cap log close
clear all
log using 100714pqregressions.log, text replace
set more off
set mem 1000m
set matsize 5000


local dopqregressions = 1
local yearFEType= "year"
local provFEType="province"
local woodFEType="wood_code"
local forestisl = 1
local dropotherwood = 1
local weight = "firstquantity"

global OUTDIR "../output/"

* UNBALANCED PANEL 
use "forest_data_bps_94.dta", clear
xtset wood_prov year
* drop "other" wood categories
if `dropotherwood'== 1 {
	drop if  type_of_wood=="LAINNYA" |  type_of_wood=="RIMBA CAMPURAN"
}

* keep forest islands only
if `forestisl' == 1 {
	keep if (substr(string(province),1,1) == "1" | substr(string(province),1,1) == "6" | substr(string(province),1,1) == "7" | province == 82)
}

* create indicators for separate samples
* 2000-2007 sample only
g yr01_07=(year>=2001)

* generate groups for FE purposes
egen provFEvar = group(`provFEType')
egen yearFEvar = group(`yearFEType')
egen woodFEvar = group(`woodFEType')
egen woodyearFEvar= group(`woodFEType' `yearFEType')
egen woodprovFEvar= group(`woodFEType' `provFEType')
g island = substr(string(province),1,1)
egen woodislyearFEvar= group(`woodFEType' `yearFEType' island)


* Determine balanced sample
preserve
use forest_data_bps_94_balanced_94_06.dta, replace
keep province type_of_wood year 
sort province type_of_wood year 
tempfile temp1
save `temp1'
restore

sort province type_of_wood year 
merge province type_of_wood year  using `temp1'
tab _merge
g balanced94_06 = (_merge == 3)
drop _merge


preserve
use forest_data_bps_94_balanced_01_07.dta, replace
keep province type_of_wood year 
sort province type_of_wood year 
tempfile temp2
save `temp2'
restore

sort province type_of_wood year 
merge province type_of_wood year  using `temp2'
tab _merge
g balanced01_07 = (_merge == 3)
drop _merge



*** run price and quantity regressions with year dummies, wood*year dummies, and prov*year,
*** and wood*island*year dummies

*** 
* regressions will include wood_island_year, and wood*prov
***


xi i.woodprovFEvar
for var _I*: ren X yd_X

****
* Table 5
****

* Regression 1: Limited to 2001-2007
areg lnprice2000usd numdistricts_dejure yd_* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}table5_a.txt, keep(numdistricts_dejure) replace excel dec(3)  ctitle("LnP- 2001-2007")

areg lnquantity numdistricts_dejure yd_* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}table5_a.txt, keep(numdistricts_dejure) append excel dec(3) ctitle("LnQ- 2001-2007")

* Regression 2: Limited to 2001-2007, balanced
areg lnprice2000usd numdistricts_dejure yd_* if yr01_07==1 & balanced01_07 == 1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}table5_a.txt, keep(numdistricts_dejure) append excel dec(3)  ctitle("LnP- 2001-2007 Balanced")

areg lnquantity numdistricts_dejure yd_* if yr01_07==1 & balanced01_07 == 1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}table5_a.txt, keep(numdistricts_dejure) append excel dec(3) ctitle("LnQ- 2001-2007 Balanced")


* Regression 3: Full sample
areg lnprice2000usd numdistricts_dejure yd_* [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}table5_a.txt, keep(numdistricts_dejure) append  excel dec(3) ctitle("LnP- Full Sample")

areg lnquantity numdistricts_dejure yd_* [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}table5_a.txt, keep(numdistricts_dejure) append excel dec(3) ctitle("LnQ- Full Sample")
 


****
* Table 5
* with lags
****
order districtslag1_dejure districtslag2_dejure districtslag3_dejure

* Regression 1: Limited to 2001-2007
areg lnprice2000usd numdistricts_dejure districtslag?_dejure yd_* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	testparm *districts*
outreg2 using ${OUTDIR}table5_b.txt, keep(*districts*) replace excel dec(3)  ctitle("LnP- 2001-2007") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

areg lnquantity numdistricts_dejure districtslag?_dejure yd_* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	testparm *districts*
outreg2 using ${OUTDIR}table5_b.txt, keep(*districts*) append excel dec(3) ctitle("LnQ- 2001-2007") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')
 
 
 * Regression 2: Limited to 2001-2007, balanced
areg lnprice2000usd numdistricts_dejure districtslag?_dejure yd_* if yr01_07==1 & balanced01_07 == 1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	testparm *districts*
outreg2 using ${OUTDIR}table5_b.txt, keep(*districts*) append excel dec(3)  ctitle("LnP- 2001-2007, Balanced") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')


areg lnquantity numdistricts_dejure districtslag?_dejure yd_* if yr01_07==1 & balanced01_07 == 1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	testparm *districts*
outreg2 using ${OUTDIR}table5_b.txt, keep(*districts*) append excel dec(3) ctitle("LnQ- 2001-2007, Balanced") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

 * Regression 3: Full sample
areg lnprice2000usd numdistricts_dejure districtslag?_dejure yd_* [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	testparm *districts*
outreg2 using ${OUTDIR}table5_b.txt, keep(*districts*) append  excel dec(3) ctitle("LnP- Full Sample")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

areg lnquantity numdistricts_dejure districtslag?_dejure yd_* [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	testparm *districts*
outreg2 using ${OUTDIR}table5_b.txt, keep(*districts*) append excel dec(3) ctitle("LnQ- Full Sample") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')



***
* Appendix Table A10
* Robustnes checks
****

************
* Panel A: Contemp weighting, de jure
************

* Regression 1: Limited to 2001-2007
areg lnprice2000usd numdistricts_dejure yd_* if yr01_07==1 [w=quantity], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA10_a.txt, keep(numdistricts_dejure) replace excel dec(3)  ctitle("LnP- 2001-2007")

areg lnquantity numdistricts_dejure yd_* if yr01_07==1 [w=quantity], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA10_a.txt, keep(numdistricts_dejure) append excel dec(3) ctitle("LnQ- 2001-2007")

* Regression 2: Limited to 2001-2007, balanced
areg lnprice2000usd numdistricts_dejure yd_* if yr01_07==1 & balanced01_07 == 1 [w=quantity], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA10_a.txt, keep(numdistricts_dejure) append excel dec(3)  ctitle("LnP- 2001-2007 Balanced")

areg lnquantity numdistricts_dejure yd_* if yr01_07==1 & balanced01_07 == 1 [w=quantity], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA10_a.txt, keep(numdistricts_dejure) append excel dec(3) ctitle("LnQ- 2001-2007 Balanced")


* Regression 3: Full sample
areg lnprice2000usd numdistricts_dejure yd_* [w=quantity], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA10_a.txt, keep(numdistricts_dejure) append  excel dec(3) ctitle("LnP- Full Sample")

areg lnquantity numdistricts_dejure yd_* [w=quantity], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA10_a.txt, keep(numdistricts_dejure) append excel dec(3) ctitle("LnQ- Full Sample")
 

************
* Panel B: Districts No CIty
************

* Regression 1: Limited to 2001-2007
areg lnprice2000usd districtsnocity yd_* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA10_b.txt, keep(districtsnocity) replace excel dec(3)  ctitle("LnP- 2001-2007")

areg lnquantity districtsnocity yd_* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA10_b.txt, keep(districtsnocity) append excel dec(3) ctitle("LnQ- 2001-2007")

* Regression 2: Limited to 2001-2007, balanced
areg lnprice2000usd districtsnocity yd_* if yr01_07==1 & balanced01_07 == 1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA10_b.txt, keep(districtsnocity) append excel dec(3)  ctitle("LnP- 2001-2007 Balanced")

areg lnquantity districtsnocity yd_* if yr01_07==1 & balanced01_07 == 1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA10_b.txt, keep(districtsnocity) append excel dec(3) ctitle("LnQ- 2001-2007 Balanced")


* Regression 3: Full sample
areg lnprice2000usd districtsnocity yd_* [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA10_b.txt, keep(districtsnocity) append  excel dec(3) ctitle("LnP- Full Sample")

areg lnquantity districtsnocity yd_* [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA10_b.txt, keep(districtsnocity) append excel dec(3) ctitle("LnQ- Full Sample")
 
************
* Panel C: Falsification: Cities
************
g districtscity = districts - districtsnocity

* Regression 1: Limited to 2001-2007
areg lnprice2000usd districtscity yd_* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA10_c.txt, keep(districtscity) replace excel dec(3)  ctitle("LnP- 2001-2007")

areg lnquantity districtscity yd_* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA10_c.txt, keep(districtscity) append excel dec(3) ctitle("LnQ- 2001-2007")

* Regression 2: Limited to 2001-2007, balanced
areg lnprice2000usd districtscity yd_* if yr01_07==1 & balanced01_07 == 1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA10_c.txt, keep(districtscity) append excel dec(3)  ctitle("LnP- 2001-2007 Balanced")

areg lnquantity districtscity yd_* if yr01_07==1 & balanced01_07 == 1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA10_c.txt, keep(districtscity) append excel dec(3) ctitle("LnQ- 2001-2007 Balanced")


* Regression 3: Full sample
areg lnprice2000usd districtscity yd_* [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA10_c.txt, keep(districtscity) append  excel dec(3) ctitle("LnP- Full Sample")

areg lnquantity districtscity yd_* [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA10_c.txt, keep(districtscity) append excel dec(3) ctitle("LnQ- Full Sample")
 
*****
* Panel D: Lags and leads
*****

****
* Table 3
* Districts -- 3 leads + 3 lags
****
order districtslag1_dejure districtslag2_dejure districtslag3_dejure districtslead1_dejure districtslead2_dejure districtslead3_dejure

* Regression 1: Limited to 2001-2007
areg lnprice2000usd numdistricts_dejure districtslag?_dejure districtslead?_dejure yd_* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	lincom districtslead1_dejure + districtslead2_dejure + districtslead3_dejure
	local sumleads = r(estimate)
	local sumleadsse = r(se)
	test districtslead1_dejure + districtslead2_dejure + districtslead3_dejure = 0
	local sumleadsp = r(p)
	testparm *districtslead*
	local jointpleads = r(p)
	testparm *districts*	
outreg2 using ${OUTDIR}tableA10_d.txt, keep(*districts*) replace excel dec(3)  ctitle("LnP- 2001-2007") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Sum leads",`sumleads',"Sum leads se",`sumleadsse',"Sum leads p",`sumleadsp',"Joint p leads ",`jointpleads')

areg lnquantity numdistricts_dejure districtslag?_dejure districtslead?_dejure yd_* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	lincom districtslead1_dejure + districtslead2_dejure + districtslead3_dejure
	local sumleads = r(estimate)
	local sumleadsse = r(se)
	test districtslead1_dejure + districtslead2_dejure + districtslead3_dejure = 0
	local sumleadsp = r(p)
	testparm *districtslead*
	local jointpleads = r(p)
	testparm *districts*	
outreg2 using ${OUTDIR}tableA10_d.txt, keep(*districts*) append excel dec(3) ctitle("LnQ- 2001-2007") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Sum leads",`sumleads',"Sum leads se",`sumleadsse',"Sum leads p",`sumleadsp',"Joint p leads ",`jointpleads')



* Regression 2: Limited to 2001-2007, Balanced
areg lnprice2000usd numdistricts_dejure districtslag?_dejure districtslead?_dejure yd_* if yr01_07==1 & balanced01_07 == 1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	lincom districtslead1_dejure + districtslead2_dejure + districtslead3_dejure
	local sumleads = r(estimate)
	local sumleadsse = r(se)
	test districtslead1_dejure + districtslead2_dejure + districtslead3_dejure = 0
	local sumleadsp = r(p)
	testparm *districtslead*
	local jointpleads = r(p)
	testparm *districts*	
outreg2 using ${OUTDIR}tableA10_d.txt, keep(*districts*) append excel dec(3)  ctitle("LnP- 2001-2007, Balanced") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Sum leads",`sumleads',"Sum leads se",`sumleadsse',"Sum leads p",`sumleadsp',"Joint p leads ",`jointpleads')

areg lnquantity numdistricts_dejure districtslag?_dejure districtslead?_dejure yd_* if yr01_07==1 & balanced01_07 == 1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	lincom districtslead1_dejure + districtslead2_dejure + districtslead3_dejure
	local sumleads = r(estimate)
	local sumleadsse = r(se)
	test districtslead1_dejure + districtslead2_dejure + districtslead3_dejure = 0
	local sumleadsp = r(p)
	testparm *districtslead*
	local jointpleads = r(p)
	testparm *districts*	
outreg2 using ${OUTDIR}tableA10_d.txt, keep(*districts*) append excel dec(3) ctitle("LnQ- 2001-2007, Balanced") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Sum leads",`sumleads',"Sum leads se",`sumleadsse',"Sum leads p",`sumleadsp',"Joint p leads ",`jointpleads')


* Regression 3: Full sample
areg lnprice2000usd numdistricts_dejure districtslag?_dejure districtslead?_dejure yd_* [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	lincom districtslead1_dejure + districtslead2_dejure + districtslead3_dejure
	local sumleads = r(estimate)
	local sumleadsse = r(se)
	test districtslead1_dejure + districtslead2_dejure + districtslead3_dejure = 0
	local sumleadsp = r(p)
	testparm *districtslead*
	local jointpleads = r(p)
	testparm *districts*	
outreg2 using ${OUTDIR}tableA10_d.txt, keep(*districts*) append excel dec(3) ctitle("LnP- Full Sample")  adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Sum leads",`sumleads',"Sum leads se",`sumleadsse',"Sum leads p",`sumleadsp',"Joint p leads ",`jointpleads')

areg lnquantity numdistricts_dejure districtslag?_dejure districtslead?_dejure yd_* [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	lincom districtslead1_dejure + districtslead2_dejure + districtslead3_dejure
	local sumleads = r(estimate)
	local sumleadsse = r(se)
	test districtslead1_dejure + districtslead2_dejure + districtslead3_dejure = 0
	local sumleadsp = r(p)
	testparm *districtslead*
	local jointpleads = r(p)
	testparm *districts*	
outreg2 using ${OUTDIR}tableA10_d.txt, keep(*districts*) append excel dec(3) ctitle("LnQ- Full Sample") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp',"Sum leads",`sumleads',"Sum leads se",`sumleadsse',"Sum leads p",`sumleadsp',"Joint p leads ",`jointpleads')
 


********
* Prov-specific trends
********

preserve
use "../Satellite Data/provdata_qje",clear
g province = prov2008

replace province="14" if province=="21"
replace province="16" if province=="19"
replace province="32" if province=="36"
replace province="71" if province=="75"
replace province="73" if province=="76"
replace province="81" if province=="82"
replace province="82" if (province=="91" | province=="94")

destring province,replace

*** weighted avg pcexp
g pcexppop = pcexp*pop

collapse (sum) totalforest2000 pop00 pcexppop, by(province)
g pcexp = pcexppop/pcexppop
tempfile temp1
sort province
save `temp1'
restore
sort province
merge n:1 province using `temp1'
tab _merge
*assert _merge == 3 if lnprice != .
drop _merge

areg lnprice2000usd numdistricts_dejure yd_* if yr01_07==1 & pcexp != . [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA11_a.txt, keep(numdistricts_dejure) replace excel dec(3)  ctitle("LnP- 2001-2007")


**
* PcExp * trend
**
cap drop _I*
for var pcexp : g _I_yr_X = (year-2000)*X

areg lnprice2000usd numdistricts_dejure yd_* _I* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA11_a.txt, keep(numdistricts_dejure) append excel dec(3)  ctitle("LnP- 2001-2007")

**
* Pop * trend
**
cap drop _I*
for var pop00 : g _I_yr_X = (year-2000)*X

areg lnprice2000usd numdistricts_dejure yd_* _I* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA11_a.txt, keep(numdistricts_dejure) append excel dec(3)  ctitle("LnP- 2001-2007")
		

**
* Forest * trend
**

cap drop _I*
for var totalforest2000: g _I_yr_X = (year-2000)*X

areg lnprice2000usd numdistricts_dejure yd_* _I* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA11_a.txt, keep(numdistricts_dejure) append excel dec(3)  ctitle("LnP- 2001-2007")


**
* PcExp, Pop, FOrest * trend
**
cap drop _I*
for var pcexp pop00 totalforest2000: g _I_yr_X = (year-2000)*X

areg lnprice2000usd numdistricts_dejure yd_* _I* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA11_a.txt, keep(numdistricts_dejure) append excel dec(3)  ctitle("LnP- 2001-2007")


** province specific linear trend
cap drop _I*
xi i.province|year
drop _Iprovince*

areg lnprice2000usd numdistricts_dejure yd_* _I* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA11_a.txt, keep(numdistricts_dejure) append excel dec(3)  ctitle("LnP- 2001-2007")


**************
* W lags
**************



areg lnprice2000usd numdistricts_dejure districtslag?_dejure  yd_* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	testparm *districts*
outreg2 using ${OUTDIR}tableA11_b.txt, keep(*districts*) replace excel dec(3)  ctitle("LnP- 2001-2007") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')


**
* PcExp * trend
**
cap drop _I*
for var pcexp : g _I_yr_X = (year-2000)*X


areg lnprice2000usd numdistricts_dejure districtslag?_dejure _I* yd_* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	testparm *districts*
outreg2 using ${OUTDIR}tableA11_b.txt, keep(*districts*) append excel dec(3)  ctitle("LnP- 2001-2007") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

**
* Pop * trend
**
cap drop _I*
for var pop00 : g _I_yr_X = (year-2000)*X


areg lnprice2000usd numdistricts_dejure districtslag?_dejure _I* yd_* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	testparm *districts*
outreg2 using ${OUTDIR}tableA11_b.txt, keep(*districts*) append excel dec(3)  ctitle("LnP- 2001-2007") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')


**
* Forest * trend
**

cap drop _I*
for var totalforest2000: g _I_yr_X = (year-2000)*X

areg lnprice2000usd numdistricts_dejure districtslag?_dejure _I* yd_* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	testparm *districts*
outreg2 using ${OUTDIR}tableA11_b.txt, keep(*districts*) append excel dec(3)  ctitle("LnP- 2001-2007") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')


**
* PcExp, Pop, FOrest * trend
**
cap drop _I*
for var pcexp pop00 totalforest2000: g _I_yr_X = (year-2000)*X

areg lnprice2000usd numdistricts_dejure districtslag?_dejure _I* yd_* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	testparm *districts*
outreg2 using ${OUTDIR}tableA11_b.txt, keep(*districts*) append excel dec(3)  ctitle("LnP- 2001-2007") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')


** province specific linear trend
cap drop _I*
xi i.province|year
drop _Iprovince*

areg lnprice2000usd numdistricts_dejure districtslag?_dejure _I* yd_* if yr01_07==1 [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	testparm *districts*
outreg2 using ${OUTDIR}tableA11_b.txt, keep(*districts*) append excel dec(3)  ctitle("LnP- 2001-2007") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')


********
* Full sample
********

areg lnprice2000usd numdistricts_dejure yd_* if pcexp != . [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA11_c.txt.out, keep(numdistricts_dejure) replace excel dec(3)  ctitle("LnP- 2001-2007")


**
* PcExp * trend
**
cap drop _I*
for var pcexp : g _I_yr_X = (year-2000)*X

areg lnprice2000usd numdistricts_dejure yd_* _I*  [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA11_c.txt.out, keep(numdistricts_dejure) append excel dec(3)  ctitle("LnP- 2001-2007")

**
* Pop * trend
**
cap drop _I*
for var pop00 : g _I_yr_X = (year-2000)*X

areg lnprice2000usd numdistricts_dejure yd_* _I*  [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA11_c.txt.out, keep(numdistricts_dejure) append excel dec(3)  ctitle("LnP- 2001-2007")
		

**
* Forest * trend
**

cap drop _I*
for var totalforest2000: g _I_yr_X = (year-2000)*X

areg lnprice2000usd numdistricts_dejure yd_* _I*  [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA11_c.txt.out, keep(numdistricts_dejure) append excel dec(3)  ctitle("LnP- 2001-2007")


**
* PcExp, Pop, FOrest * trend
**
cap drop _I*
for var pcexp pop00 totalforest2000: g _I_yr_X = (year-2000)*X

areg lnprice2000usd numdistricts_dejure yd_* _I*  [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA11_c.txt.out, keep(numdistricts_dejure) append excel dec(3)  ctitle("LnP- 2001-2007")


** province specific linear trend
cap drop _I*
xi i.province|year
drop _Iprovince*

areg lnprice2000usd numdistricts_dejure yd_* _I*  [w=`weight'], cluster(province) absorb(woodislyearFEvar)
outreg2 using ${OUTDIR}tableA11_c.txt.out, keep(numdistricts_dejure) append excel dec(3)  ctitle("LnP- 2001-2007")


**************
* W lags
**************



areg lnprice2000usd numdistricts_dejure districtslag?_dejure  yd_*  [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	testparm *districts*
outreg2 using ${OUTDIR}tableA11_d.txt, keep(*districts*) replace excel dec(3)  ctitle("LnP- 2001-2007") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')


**
* PcExp * trend
**
cap drop _I*
for var pcexp : g _I_yr_X = (year-2000)*X


areg lnprice2000usd numdistricts_dejure districtslag?_dejure _I* yd_*  [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	testparm *districts*
outreg2 using ${OUTDIR}tableA11_d.txt, keep(*districts*) append excel dec(3)  ctitle("LnP- 2001-2007") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')

**
* Pop * trend
**
cap drop _I*
for var pop00 : g _I_yr_X = (year-2000)*X


areg lnprice2000usd numdistricts_dejure districtslag?_dejure _I* yd_*  [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	testparm *districts*
outreg2 using ${OUTDIR}tableA11_d.txt, keep(*districts*) append excel dec(3)  ctitle("LnP- 2001-2007") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')


**
* Forest * trend
**

cap drop _I*
for var totalforest2000: g _I_yr_X = (year-2000)*X

areg lnprice2000usd numdistricts_dejure districtslag?_dejure _I* yd_*  [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	testparm *districts*
outreg2 using ${OUTDIR}tableA11_d.txt, keep(*districts*) append excel dec(3)  ctitle("LnP- 2001-2007") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')


**
* PcExp, Pop, FOrest * trend
**
cap drop _I*
for var pcexp pop00 totalforest2000: g _I_yr_X = (year-2000)*X

areg lnprice2000usd numdistricts_dejure districtslag?_dejure _I* yd_*  [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	testparm *districts*
outreg2 using ${OUTDIR}tableA11_d.txt, keep(*districts*) append excel dec(3)  ctitle("LnP- 2001-2007") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')


** province specific linear trend
cap drop _I*
xi i.province|year
drop _Iprovince*

areg lnprice2000usd numdistricts_dejure districtslag?_dejure _I* yd_*  [w=`weight'], cluster(province) absorb(woodislyearFEvar)
	lincom numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure
	local sumlags = r(estimate)
	local sumlagsse = r(se)
	test numdistricts_dejure + districtslag1_dejure + districtslag2_dejure + districtslag3_dejure = 0
	local sumlagsp = r(p)
	testparm *districts*
outreg2 using ${OUTDIR}tableA11_d.txt, keep(*districts*) append excel dec(3)  ctitle("LnP- 2001-2007") adds("Joint P",r(p),"Sum lags",`sumlags',"Sum lags se",`sumlagsse',"Sum lags p",`sumlagsp')


